package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.auth.feign.UserFeign;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.request.UserLoginReq;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.domain.response.UserLoginResp;
import com.bwie.common.exception.AllException;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.SendMessageUtil;
import com.bwie.common.utils.StringUtils;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.data.redis.core.ValueOperations;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;
import java.util.Random;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

@Log4j2
@Service
public class AuthServiceImpl implements AuthService {

    @Autowired
    private UserFeign userFeign;

    @Autowired
    private StringRedisTemplate redisTemplate;

    /**
     * 发送验证码
     * @param req
     * @return
     */
    @Override
    public void getCode(UserLoginReq req) {
        if (StringUtils.isEmpty(req.getUserTel())){
            throw new AllException("手机号不能为空");
        }
        Result<UserLoginResp> respResult = userFeign.findByTel(req.getUserTel());
        if (respResult.getCode()!=200){
            throw new AllException(respResult.getMsg());
        }
        UserLoginResp userLoginResp = respResult.getData();
        if (userLoginResp==null){
            throw new AllException("手机号不存在");
        }
        SendMessageUtil sendMessageUtil = new SendMessageUtil();
        Random random = new Random();
        int code = random.nextInt(9000) + 1000;
        sendMessageUtil.sendSms(userLoginResp.getUserTel(),String.valueOf(code));
        log.info("验证码---->{}",code);
        redisTemplate.opsForValue().set(
                "code:"+userLoginResp.getUserTel(),
                String.valueOf(code),
                10,
                TimeUnit.MINUTES
        );
    }

    @Override
    public JwtResponse login(UserLoginReq req) {
        if (StringUtils.isEmpty(req.getUserTel())){
            throw new AllException("手机号不能为空");
        }
        if (StringUtils.isEmpty(req.getCode())){
            throw new AllException("验证码不能为空");
        }

        Result<UserLoginResp> respResult = userFeign.findByTel(req.getUserTel());
        if (respResult.getCode()!=200){
            throw new AllException(respResult.getMsg());
        }
        UserLoginResp userLoginResp = respResult.getData();
        if (userLoginResp==null){
            throw new AllException("手机号不存在");
        }
        ValueOperations<String, String> ops = redisTemplate.opsForValue();
        String code = ops.get("code:" + userLoginResp.getUserTel());
        if (!req.getCode().equals(code)){
            throw new AllException("验证码错误");
        }
        Map<String, Object> map = new HashMap<>();
        String userKey = UUID.randomUUID().toString();
        map.put(JwtConstants.USER_KEY,userKey);
        map.put(JwtConstants.DETAILS_USER_ID,userLoginResp.getUserId());
        String token = JwtUtils.createToken(map);
        ops.set(TokenConstants.LOGIN_TOKEN_KEY+userKey, JSON.toJSONString(userLoginResp),300,TimeUnit.MINUTES);
        JwtResponse jwtResponse = JwtResponse.builder().token(token).existTime("300MIN").build();
        return jwtResponse;
    }

    @Override
    public UserLoginResp info(HttpServletRequest req) {
        String token = req.getHeader(TokenConstants.TOKEN);
        String userKey = JwtUtils.getUserKey(token);
        String jsonUser = redisTemplate.opsForValue().get(TokenConstants.LOGIN_TOKEN_KEY + userKey);
        UserLoginResp userLoginResp = JSON.parseObject(jsonUser, UserLoginResp.class);
        return userLoginResp;
    }
}
