package com.bwie.message.consumer;


import com.bwie.common.utils.SendMessageUtil;
import com.rabbitmq.client.Channel;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.HashMap;

@Log4j2
@Component
public class SendMessageConsumer {
    @Autowired
    private StringRedisTemplate redisTemplate;

    @RabbitListener(queuesToDeclare = @Queue("SEND_MESSAGE"))
    public void sendMessage(HashMap<String,String> map, Message message, Channel channel){

        log.info("----MQ启动-----");
        String messageId = message.getMessageProperties().getMessageId();
        Long sendMessage = redisTemplate.opsForSet().add("SEND_MESSAGE", messageId);
        if (sendMessage>0){
            SendMessageUtil sendMessageUtil = new SendMessageUtil();
            log.info("开的发送消息");
            String userTel = map.get("userTel");
            String text = map.get("text");
            log.info("电话号码:{} 消息内容:{}",userTel, text);
            sendMessageUtil.sendSms(userTel,text);
            log.info("发送成功");
            try {
                channel.basicAck(message.getMessageProperties().getDeliveryTag(),false);
            } catch (IOException e) {
                redisTemplate.opsForSet().remove("SEND_MESSAGE", messageId);
                try {
                    channel.basicReject(message.getMessageProperties().getDeliveryTag(),true);
                } catch (IOException ex) {
                    throw new RuntimeException(ex);
                }
            }
        }
    }


}
