package com.bwie.service.impl;

import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.Candidate;
import com.bwie.common.domain.request.CandidateAddReq;
import com.bwie.common.domain.response.CandidateResp;
import com.bwie.common.exception.AllException;
import com.bwie.common.utils.JwtUtils;
import com.bwie.feign.UserFeign;
import com.bwie.mapper.CandidateMapper;
import com.bwie.service.CandidateService;
import com.bwie.service.RecruitmentService;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.UUID;

@Service
public class CandidateServiceImpl implements CandidateService {
    @Autowired
    private CandidateMapper candidateMapper;

    @Autowired
    private RecruitmentService recruitmentService;

    @Autowired
    private UserFeign userFeign;

    @Autowired
    private RabbitTemplate rabbitTemplate;

    @Autowired
    private HttpServletRequest request;
    @Override
    public int addCandidate(CandidateAddReq req) {
        String token = request.getHeader(TokenConstants.TOKEN);
        String userId = JwtUtils.getUserId(token);
        boolean estimate = this.estimate(Integer.valueOf(userId), req.getRecruitmentId());
        if (estimate){
            throw new AllException("该岗位已投递");
        }
        Candidate build = Candidate.builder().userId(Integer.valueOf(userId))
                .money(req.getMoney())
                .recruitmentId(req.getRecruitmentId())
                .time(new Date())
                .build();
        int i = candidateMapper.addCandidate(build);
        if (i>0){
            recruitmentService.updNumber(req.getRecruitmentId());
            userFeign.updNumber(userId);
        }
        return i;
    }

    @Override
    public List<CandidateResp> findList() {
        return candidateMapper.findList();
    }

    @Override
    public int examine(Integer id, Integer status, String userTel) {
        HashMap<String, String> map = new HashMap<>();
        int examine = candidateMapper.examine(id, status);
        if (examine>0){
            if (status==2){
                map.put("userTel",userTel);
                map.put("text","恭喜你 你的简历已经通过 请前来面试");
            }else {
                map.put("userTel",userTel);
                map.put("text","很遗憾 你的简历不符合岗位要求 请再接再厉");
            }
            rabbitTemplate.convertAndSend("SEND_MESSAGE",map,message -> {
                message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                return message;
            });
        }
        return examine;
    }

    private boolean estimate(Integer userId ,Integer recruitmentId){
        Candidate candidate = candidateMapper.selectByUserIdAndRecruitmentId(userId, recruitmentId);
        return candidate==null?false:true;
    }
}
